<?php
/**
*
* @package Scroll Quoted Text
* @copyright (c) 2020 HiFiKabin
* @license http://opensource.org/licenses/gpl-2.0.php GNU General Public License v2
*
*/

namespace hifikabin\scrollquoted\event;

/**
* @ignore
*/
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
* Event listener
*/
class listener implements EventSubscriberInterface
{
	/** @var \phpbb\request\request */
	protected $request;

	/** @var \phpbb\template\template */
	protected $template;

	/** @var \phpbb\user */
	protected $user;

	/**
	* Constructor
	*/
	public function __construct(\phpbb\request\request $request, \phpbb\template\template $template, \phpbb\user $user)
	{
		$this->request 		= $request;
		$this->template 	= $template;
		$this->user 		= $user;
	}

	/**
	* Assign functions
	*/
	static public function getSubscribedEvents()
	{
		return array(
			'core.page_header'					=> 'include_css_in_template',
			'core.ucp_prefs_view_data'			=> 'ucp_prefs_add',
			'core.ucp_prefs_view_update_data'	=> 'ucp_prefs_update',
		);
	}

	/**
	* Includes CSS in template if the radiobox in UCP was selected
	*/
	public function include_css_in_template($event)
	{
		$this->template->assign_vars(array(
			'S_SCROLLQUOTED'	=> $this->user->data['scrollquoted'],
		));
	}

	/**
	* Add configuration to UCP
	*/
	public function ucp_prefs_add($event)
	{
		$this->user->add_lang_ext('hifikabin/scrollquoted', 'scrollquoted');

		$scrollquoted = $this->request->variable('scrollquoted', (bool) $this->user->data['scrollquoted']);
		$event['data'] = array_merge($event['data'], array(
			'scrollquoted'	=> $scrollquoted,
		));

		$this->template->assign_vars(array(
			'S_SCROLLQUOTED'	=> $scrollquoted,
		));
	}

	/**
	* Updates configuration in UCP
	*/
	public function ucp_prefs_update($event)
	{
		$event['sql_ary'] = array_merge($event['sql_ary'], array(
			'scrollquoted'		=> $event['data']['scrollquoted'],
		));
	}
}
